@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.01_03';
+our $VERSION = '0.01_04';
 
 use AnyEvent::RipeRedis::Error;
 
@@ -1280,8 +1280,7 @@ Enabled by default.
 =item min_reconnect_interval => $fractional_seconds
 
 If the parameter is specified, the client will try to reconnect not often than
-through this interval. Command executions between reconnections in this case
-will be suspended.
+through this interval.
 
   min_reconnect_interval => 5,
 
@@ -1289,7 +1288,7 @@ Not set by default.
 
 =item handle_params => \%params
 
-Parameters, which will be passed to L<AnyEvent::Handle> constructor.
+Specifies L<AnyEvent::Handle> parameters.
 
   handle_params => {
     linger   => 60,
@@ -1372,8 +1371,8 @@ The full list of the Redis commands can be found here: L<http://redis.io/command
         return;
       }
 
-      foreach my $val ( @{$reply}  ) {
-        print "$val\n";
+      foreach my $value ( @{$reply}  ) {
+        print "$value\n";
       }
     }
   );
@@ -1412,7 +1411,7 @@ objects for every failed command.
 
         if ( defined $reply ) {
           foreach my $nested_reply ( @{$reply} ) {
-            if ( ref($reply) eq 'AnyEvent::RipeRedis::Error' ) {
+            if ( ref($nested_reply) eq 'AnyEvent::RipeRedis::Error' ) {
               my $nested_err_msg  = $nested_reply->message();
               my $nested_err_code = $nested_reply->code();
 
@@ -1462,10 +1461,10 @@ Subscribes the client to the specified channels. Method can accept two
 callbacks: C<on_reply> and C<on_message>. The C<on_reply> callback is called
 once when subscription to all specified channels will be activated. In first
 argument to the callback is passed the number of channels we are currently
-subscribed. If error occurred during subscription operation or subscription to
-specified channels was lost, to the C<on_reply> callback will be passed error
-objec. The C<on_message> callback is called on every published message. If
-method is called with one callback, it will be act as C<on_message> callback.
+subscribed. If subscription to specified channels was lost, the C<on_reply>
+callback is called with the error object in the second argument. The
+C<on_message> callback is called on every published message. If method is
+called with one callback, it will be act as C<on_message> callback.
 
   $redis->subscribe( qw( foo bar ),
     { on_reply => sub {
@@ -1478,7 +1477,7 @@ method is called with one callback, it will be act as C<on_message> callback.
           return;
         }
 
-        # handling...
+        # reply handling...
       },
 
       on_message => sub {
@@ -1624,8 +1623,8 @@ instead.
         return;
       }
 
-      foreach my $val ( @{$reply}  ) {
-        print "$val\n";
+      foreach my $value ( @{$reply}  ) {
+        print "$value\n";
       }
     }
   );
@@ -1648,7 +1647,7 @@ will be contain nested error objects.
 
         if ( defined $reply ) {
           foreach my $nested_reply ( @{$reply} ) {
-            if ( ref($reply) eq 'AnyEvent::RipeRedis::Error' ) {
+            if ( ref($nested_reply) eq 'AnyEvent::RipeRedis::Error' ) {
               my $nested_err_msg  = $nested_reply->message();
               my $nested_err_code = $nested_reply->code();
 
@@ -1850,7 +1849,7 @@ Selects the database by numeric index.
 
 Get selected database index.
 
-=head2 utf8()
+=head2 utf8( [ $boolean ] )
 
 Enables or disables UTF-8 mode.
 
@@ -1889,7 +1888,7 @@ Get or set the C<on_error> callback.
 
 =head1 SEE ALSO
 
-L<AnyEvent>, L<AnyEvent::Redis>, L<Redis>, L<Redis::hiredis>, L<RedisDB>
+L<AnyEvent>, L<Redis::hiredis>, L<Redis>, L<RedisDB>
 
 =head1 AUTHOR
 
